BB.MCP.Tools.ListCommands (bb_mcp v0.1.0)

Copy Markdown View Source

List the commands declared on a robot, with their typed argument schemas.

Use the returned arguments schemas to know what to pass to the invoke_command tool.

Summary

Functions

get_schema(atom)

mcp_schema(data)

mcp_schema!(data)